Python Spatial Analysis Library Core
====================================

.. image:: https://travis-ci.org/pysal/libpysal.svg
   :target: https://travis-ci.org/pysal/libpysal

.. image:: https://badge.fury.io/py/libpysal.svg
    :target: https://badge.fury.io/py/libpysal

.. image:: https://img.shields.io/conda/vn/conda-forge/libpysal.svg
   :target: https://anaconda.org/conda-forge/libpysal

.. image:: https://zenodo.org/badge/81501824.svg
   :target: https://zenodo.org/badge/latestdoi/81501824   



****************
libpysal modules
****************

- libpysal.cg  Computational geometry
- libpysal.io  Input and output
- libpysal.weights  Spatial weights
- libpysal.examples  Built-in example datasets


*****************
Example Notebooks
*****************
- `Spatial Weights  <notebooks/weights.ipynb>`_
- `Voronoi  <notebooks/voronoi.ipynb>`_
- `Input and Output <notebooks/io.ipynb>`_

***********
Development
***********

libpysal development is hosted on github_.

.. _github : https://github.com/pysal/libpysal

Discussions of development occurs on the
`developer list <http://groups.google.com/group/pysal-dev>`_
as well as gitter_.

.. _gitter : https://gitter.im/pysal/pysal?

****************
Getting Involved
****************

If you are interested in contributing to PySAL please see our
`development guidelines  <https://github.com/pysal/pysal/wiki>`_.

***********
Bug reports
***********

To search for or report bugs, please see libpysal's issues_.

.. _issues :  http://github.com/pysal/libpysal/issues

*******************
License information
*******************

See the `LICENSE <https://github.com/pysal/libpysal/blob/master/LICENSE.txt>`_ for information on the history of this
software, terms & conditions for usage, and a DISCLAIMER OF ALL
WARRANTIES.
